---
title: Urubu 0.5 released
layout: page 
date: 2014-09-08
---

Urubu 0.5 introduces tag support. 

Read [my blog post][post] for an introduction.

[post]: http://www.jandecaluwe.com/blog/tag_support_urubu.html




